/*
 * @module threadex.h |
 *
 * Externally useable procedures from the thread library. Not the same as
 * thread.h which is just a list of prototypes for the thread class's native
 * methods.
 *
 */

#ifndef __THREADEX_H__
#define __THREADEX_H__

#include "interp.h"
#include "jni.h"

void THREAD_Destroy(tOBREF);
void THREAD_ForceThreadSwitch(tOBREF);
void THREAD_SynchroniseEnter(tOBREF);
void THREAD_SynchroniseExit(tOBREF);


#endif
